@@ -1,7 +1,7 @@
 package Data::Sah::CoerceCommon;
 
-our $DATE = '2016-05-21'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2016-05-22'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 our $gen_coercer_meta = {
     v => 1.1,
@@ -28,11 +28,11 @@ _
             schema => ['array*', of=>'str*'],
         },
         return_type => {
-            schema => ['str*', in=>[qw/val bool+val/]],
+            schema => ['str*', in=>[qw/val str+val/]],
             default => 'val',
             description => <<'_',
 
-`val` returns the value (possibly) coerced. `bool+val` returns a 2-element array
+`val` returns the value (possibly) coerced. `str+val` returns a 2-element array
 where the first element is a bool value of whether the value has been coerced,
 and the second element is the (possibly) coerced value.
 
@@ -62,7 +62,7 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.008 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2016-05-21.
+This document describes version 0.009 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2016-05-22.
 
 =head1 HOMEPAGE
 
