@@ -1,7 +1,7 @@
 package Data::Sah::CoerceJS;
 
-our $DATE = '2016-05-21'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2016-05-22'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -36,7 +36,7 @@ sub gen_coercer {
 
     my $type = $args{type};
     my $rt = $args{return_type} // 'val';
-    my $rt_bv = $rt eq 'bool+val';
+    my $rt_sv = $rt eq 'str+val';
 
     my $all_mods = _list_rule_modules();
 
@@ -73,6 +73,7 @@ sub gen_coercer {
             data_term => 'data',
             coerce_to => $args{coerce_to},
         );
+        $res->{rule} = $rule;
         push @res, $res;
     }
 
@@ -87,14 +88,14 @@ sub gen_coercer {
         for my $i (reverse 0..$#res) {
             my $res = $res[$i];
             if ($i == $#res) {
-                if ($rt_bv) {
-                    $expr = "($res->{expr_match}) ? [true, $res->{expr_coerce}] : [false, data]";
+                if ($rt_sv) {
+                    $expr = "($res->{expr_match}) ? [\"$res->{rule}\", $res->{expr_coerce}] : [null, data]";
                 } else {
                     $expr = "($res->{expr_match}) ? ($res->{expr_coerce}) : data";
                 }
             } else {
-                if ($rt_bv) {
-                    $expr = "($res->{expr_match}) ? [true, $res->{expr_coerce}] : ($expr)";
+                if ($rt_sv) {
+                    $expr = "($res->{expr_match}) ? [\"$res->{rule}\", $res->{expr_coerce}] : ($expr)";
                 } else {
                     $expr = "($res->{expr_match}) ? ($res->{expr_coerce}) : ($expr)";
                 }
@@ -104,16 +105,16 @@ sub gen_coercer {
         $code = join(
             "",
             "function (data) {\n",
-            ($rt_bv ?
-                 "    if (data === undefined || data === null) return [false, null];\n" :
+            ($rt_sv ?
+                 "    if (data === undefined || data === null) return [null, null];\n" :
                  "    if (data === undefined || data === null) return null;\n"
              ),
             "    return ($expr);\n",
             "}",
         );
     } else {
-        if ($rt_bv) {
-            $code = 'function (data) { return [false, data] }';
+        if ($rt_sv) {
+            $code = 'function (data) { return [null, data] }';
         } else {
             $code = 'function (data) { return data }';
         }
@@ -167,7 +168,7 @@ Data::Sah::CoerceJS - Generate coercer code
 
 =head1 VERSION
 
-This document describes version 0.008 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-05-21.
+This document describes version 0.009 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-05-22.
 
 =head1 SYNOPSIS
 
@@ -215,7 +216,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<return_type> => I<str> (default: "val")
 
-C<val> returns the value (possibly) coerced. C<bool+val> returns a 2-element array
+C<val> returns the value (possibly) coerced. C<str+val> returns a 2-element array
 where the first element is a bool value of whether the value has been coerced,
 and the second element is the (possibly) coerced value.
 
